@@ -546,30 +546,22 @@ and F<Sys::Hostname>.
 
 =head1 AUTHOR
 
-Glenn Wood, Glenn.Wood@SaveSmart.com
+Glenn Wood, C<glenwood@alumni.caltech.edu>.
 
 Copyright 1997-1998 SaveSmart, Inc.
 
 Released under the Perl Artistic License.
 
-$Id: loadworm.pm 1.26 1998/07/01 05:17:24 Glenn dev $
+$Id: LoadWorm.pm,v 1.1.1.1 2001/05/19 02:54:40 Glenn Wood Exp $
 
 =cut
 
-# AUTHOR Glenn Wood, Glenn.Wood@savesmart.com
-# Copyright 1997-1998 SaveSmart, Inc.
-# Copyright (c) 1997 -1998 SaveSmart, Inc. All rights reserved.
-# Released under the Perl Artistic License.
-# This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
-#
-# $Id: loadworm.pm 1.26 1998/07/01 05:17:24 Glenn dev $
-
 use LWP::Parallel::RobotUA qw(:CALLBACK);
 
 package LoadWorm;
 use English;
 
-$VERSION = do { my @r=(q $Name: r0_12 $ =~ /\d+/g ); sprintf "%d."."%02d"x$#r,@r }; 
+$VERSION = do { my @r=(q $Name:  $ =~ /\d+/g ); sprintf "%d."."%02d"x$#r,@r }; 
 
 if ( $OSNAME eq "MSWin32" )
 {
